@@ -39,7 +39,8 @@ typedef enum
     NETK_WINDOW_STATE_STICKY = 1 << 6,
     NETK_WINDOW_STATE_HIDDEN = 1 << 7,
     NETK_WINDOW_STATE_FULLSCREEN = 1 << 8,
-    NETK_WINDOW_STATE_URGENT = 1 << 9
+    NETK_WINDOW_STATE_URGENT = 1 << 9,
+    NETK_WINDOW_STATE_DEMANDS_ATTENTION = 1 << 10
 }
 NetkWindowState;
 
@@ -154,9 +155,13 @@ gboolean netk_window_is_shaded (NetkWindow * window);
 gboolean netk_window_is_skip_pager (NetkWindow * window);
 gboolean netk_window_is_skip_tasklist (NetkWindow * window);
 gboolean netk_window_is_sticky (NetkWindow * window);
+gboolean netk_window_is_fullscreen (NetkWindow * window);
+gboolean netk_window_demands_attention (NetkWindow * window);
+gboolean netk_window_or_transient_demands_attention (NetkWindow * window);
 
 void netk_window_set_skip_pager (NetkWindow * window, gboolean skip);
 void netk_window_set_skip_tasklist (NetkWindow * window, gboolean skip);
+void netk_window_set_fullscreen (NetkWindow * window, gboolean fullscreen);
 
 void netk_window_close (NetkWindow * window);
 void netk_window_minimize (NetkWindow * window);
