@@ -741,11 +741,11 @@ client_session_new_full (gpointer data, SessionRestartStyle restart_style,
     session_client->interact_style = SESSION_INTERACT_NONE;
     session_client->session_connection = NULL;
     session_client->priority = priority;
-    session_client->client_id = client_id;
+    session_client->client_id = g_strdup (client_id);
     session_client->given_client_id = NULL;
     if (program)
     {
-        session_client->program = program;
+        session_client->program = g_strdup (program);
     }
     else
     {
@@ -753,7 +753,7 @@ client_session_new_full (gpointer data, SessionRestartStyle restart_style,
     }
     if (current_directory)
     {
-        session_client->current_directory = current_directory;
+        session_client->current_directory = g_strdup (current_directory);
     }
     else
     {
@@ -820,7 +820,7 @@ client_session_new (gint argc, gchar * argv[], gpointer data,
         if ((!had_display) && (dpy != NULL))
         {
             array[i++] = "--display";
-            array[i++] = (gchar *)gdk_display_get_name(dpy);
+            array[i++] = (gchar *) gdk_display_get_name (dpy);
         }
 
         array[i] = NULL;
